@@ -3,26 +3,30 @@
 Decay
 =====
 
-A sinusoidal decay animation.
+This example showcases:
+
+- using a generator to drive an animation,
+- changing axes limits during an animation.
+
+Output generated via `matplotlib.animation.Animation.to_jshtml`.
 """
 
+import itertools
 
 import numpy as np
 import matplotlib.pyplot as plt
 import matplotlib.animation as animation
 
 
-def data_gen(t=0):
-    cnt = 0
-    while cnt < 1000:
-        cnt += 1
-        t += 0.1
+def data_gen():
+    for cnt in itertools.count():
+        t = cnt / 10
         yield t, np.sin(2*np.pi*t) * np.exp(-t/10.)
 
 
 def init():
     ax.set_ylim(-1.1, 1.1)
-    ax.set_xlim(0, 10)
+    ax.set_xlim(0, 1)
     del xdata[:]
     del ydata[:]
     line.set_data(xdata, ydata)
@@ -48,6 +52,7 @@ def run(data):
 
     return line,
 
-ani = animation.FuncAnimation(fig, run, data_gen, blit=False, interval=10,
-                              repeat=False, init_func=init)
+# Only save last 100 frames, but run forever
+ani = animation.FuncAnimation(fig, run, data_gen, interval=100, init_func=init,
+                              save_count=100)
 plt.show()
