@@ -9,9 +9,6 @@ The data used is the same as in the second plot of trisurf3d_demo2.
 tricontourf3d_demo shows the filled version of this example.
 """
 
-# This import registers the 3D projection, but is otherwise unused.
-from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
-
 import matplotlib.pyplot as plt
 import matplotlib.tri as tri
 import numpy as np
@@ -38,8 +35,7 @@ triang.set_mask(np.hypot(x[triang.triangles].mean(axis=1),
                          y[triang.triangles].mean(axis=1))
                 < min_radius)
 
-fig = plt.figure()
-ax = fig.gca(projection='3d')
+ax = plt.figure().add_subplot(projection='3d')
 ax.tricontour(triang, z, cmap=plt.cm.CMRmap)
 
 # Customize the view angle so it's easier to understand the plot.
