@@ -11,6 +11,9 @@ This demo compares:
 
 Each `.axes.Axes` has a list of `.Spine` objects, accessible
 via the container ``ax.spines``.
+
+.. redirect-from:: /gallery/spines/spines_bounds
+
 """
 import numpy as np
 import matplotlib.pyplot as plt
@@ -20,7 +23,7 @@ x = np.linspace(0, 2 * np.pi, 100)
 y = 2 * np.sin(x)
 
 # Constrained layout makes sure the labels don't overlap the axes.
-fig, (ax0, ax1, ax2) = plt.subplots(nrows=3, constrained_layout=True)
+fig, (ax0, ax1, ax2) = plt.subplots(nrows=3, layout='constrained')
 
 ax0.plot(x, y)
 ax0.set_title('normal spines')
@@ -31,20 +34,16 @@ ax1.set_title('bottom-left spines')
 # Hide the right and top spines
 ax1.spines.right.set_visible(False)
 ax1.spines.top.set_visible(False)
-# Only show ticks on the left and bottom spines
-ax1.yaxis.set_ticks_position('left')
-ax1.xaxis.set_ticks_position('bottom')
 
 ax2.plot(x, y)
+ax2.set_title('spines with bounds limited to data range')
 
-# Only draw spine between the y-ticks
-ax2.spines.left.set_bounds(-1, 1)
+# Only draw spines for the data range, not in the margins
+ax2.spines.bottom.set_bounds(x.min(), x.max())
+ax2.spines.left.set_bounds(y.min(), y.max())
 # Hide the right and top spines
 ax2.spines.right.set_visible(False)
 ax2.spines.top.set_visible(False)
-# Only show ticks on the left and bottom spines
-ax2.yaxis.set_ticks_position('left')
-ax2.xaxis.set_ticks_position('bottom')
 
 plt.show()
 
@@ -53,6 +52,5 @@ plt.show()
 #    The use of the following functions, methods, classes and modules is shown
 #    in this example:
 #
-#    - `matplotlib.Spines.set_visible`
-#    - `matplotlib.Spines.set_bounds`
-#    - `matplotlib.axis.set_ticks_position`
+#    - `matplotlib.spines.Spine.set_visible`
+#    - `matplotlib.spines.Spine.set_bounds`
