@@ -7,14 +7,13 @@ This shows how to plot a cumulative, normalized histogram as a
 step function in order to visualize the empirical cumulative
 distribution function (CDF) of a sample. We also show the theoretical CDF.
 
-A couple of other options to the ``hist`` function are demonstrated.
-Namely, we use the ``normed`` parameter to normalize the histogram and
-a couple of different options to the ``cumulative`` parameter.
-The ``normed`` parameter takes a boolean value. When ``True``, the bin
-heights are scaled such that the total area of the histogram is 1. The
-``cumulative`` kwarg is a little more nuanced. Like ``normed``, you
-can pass it True or False, but you can also pass it -1 to reverse the
-distribution.
+A couple of other options to the ``hist`` function are demonstrated. Namely, we
+use the *normed* parameter to normalize the histogram and a couple of different
+options to the *cumulative* parameter. The *normed* parameter takes a boolean
+value. When ``True``, the bin heights are scaled such that the total area of
+the histogram is 1. The *cumulative* keyword argument is a little more nuanced.
+Like *normed*, you can pass it True or False, but you can also pass it -1 to
+reverse the distribution.
 
 Since we're showing a normalized and cumulative histogram, these curves
 are effectively the cumulative distribution functions (CDFs) of the
@@ -25,7 +24,7 @@ from the sample not exceeding that x-value. For example, the value of
 225 on the x-axis corresponds to about 0.85 on the y-axis, so there's an
 85% chance that an observation in the sample does not exceed 225.
 Conversely, setting, ``cumulative`` to -1 as is done in the
-last series for this example, creates a "exceedance" curve.
+last series for this example, creates an "exceedance" curve.
 
 Selecting different bin counts and sizes can significantly affect the
 shape of a histogram. The Astropy docs have a great section on how to
