@@ -1,20 +1,26 @@
 /* -*- mode: c++; c-basic-offset: 4 -*- */
 
 /* A python interface to FreeType */
+#pragma once
 #ifndef MPL_FT2FONT_H
 #define MPL_FT2FONT_H
 #include <vector>
 #include <stdint.h>
+#include <unordered_map>
 
 extern "C" {
 #include <ft2build.h>
 #include FT_FREETYPE_H
 #include FT_GLYPH_H
+#include FT_OUTLINE_H
 #include FT_SFNT_NAMES_H
 #include FT_TYPE1_TABLES_H
 #include FT_TRUETYPE_TABLES_H
 }
 
+#define PY_SSIZE_T_CLEAN
+#include <Python.h>
+
 /*
  By definition, FT_FIXED as 2 16bit values stored in a single long.
  */
@@ -65,7 +71,7 @@ class FT2Font
 {
 
   public:
-    FT2Font(FT_Open_Args &open_args, long hinting_factor);
+    FT2Font(FT_Open_Args &open_args, long hinting_factor, std::vector<FT2Font *> &fallback_list);
     virtual ~FT2Font();
     void clear();
     void set_size(double ptsize, double dpi);
@@ -73,9 +79,21 @@ class FT2Font
     void select_charmap(unsigned long i);
     void set_text(
         size_t N, uint32_t *codepoints, double angle, FT_Int32 flags, std::vector<double> &xys);
-    int get_kerning(FT_UInt left, FT_UInt right, FT_UInt mode);
+    int get_kerning(FT_UInt left, FT_UInt right, FT_UInt mode, bool fallback);
+    int get_kerning(FT_UInt left, FT_UInt right, FT_UInt mode, FT_Vector &delta);
     void set_kerning_factor(int factor);
-    void load_char(long charcode, FT_Int32 flags);
+    void load_char(long charcode, FT_Int32 flags, FT2Font *&ft_object, bool fallback);
+    bool load_char_with_fallback(FT2Font *&ft_object_with_glyph,
+                                 FT_UInt &final_glyph_index,
+                                 std::vector<FT_Glyph> &parent_glyphs,
+                                 std::unordered_map<long, FT2Font *> &parent_char_to_font,
+                                 std::unordered_map<FT_UInt, FT2Font *> &parent_glyph_to_font,
+                                 long charcode,
+                                 FT_Int32 flags,
+                                 FT_Error &charcode_error,
+                                 FT_Error &glyph_error,
+                                 bool override);
+    void load_glyph(FT_UInt glyph_index, FT_Int32 flags, FT2Font *&ft_object, bool fallback);
     void load_glyph(FT_UInt glyph_index, FT_Int32 flags);
     void get_width_height(long *width, long *height);
     void get_bitmap_offset(long *x, long *y);
@@ -85,41 +103,51 @@ class FT2Font
     void get_xys(bool antialiased, std::vector<double> &xys);
     void draw_glyphs_to_bitmap(bool antialiased);
     void draw_glyph_to_bitmap(FT2Image &im, int x, int y, size_t glyphInd, bool antialiased);
-    void get_glyph_name(unsigned int glyph_number, char *buffer);
+    void get_glyph_name(unsigned int glyph_number, char *buffer, bool fallback);
     long get_name_index(char *name);
-    int get_path_count();
-    void get_path(double *outpoints, unsigned char *outcodes);
+    FT_UInt get_char_index(FT_ULong charcode, bool fallback);
+    void get_cbox(FT_BBox &bbox);
+    PyObject* get_path();
+    bool get_char_fallback_index(FT_ULong charcode, int& index) const;
 
-    FT_Face &get_face()
+    FT_Face const &get_face() const
     {
         return face;
     }
+
     FT2Image &get_image()
     {
         return image;
     }
-    FT_Glyph &get_last_glyph()
+    FT_Glyph const &get_last_glyph() const
     {
         return glyphs.back();
     }
-    size_t get_last_glyph_index()
+    size_t get_last_glyph_index() const
     {
         return glyphs.size() - 1;
     }
-    size_t get_num_glyphs()
+    size_t get_num_glyphs() const
     {
         return glyphs.size();
     }
-    long get_hinting_factor()
+    long get_hinting_factor() const
     {
         return hinting_factor;
     }
+    FT_Bool has_kerning() const
+    {
+        return FT_HAS_KERNING(face);
+    }
 
   private:
     FT2Image image;
     FT_Face face;
     FT_Vector pen;    /* untransformed origin  */
     std::vector<FT_Glyph> glyphs;
+    std::vector<FT2Font *> fallbacks;
+    std::unordered_map<FT_UInt, FT2Font *> glyph_to_font;
+    std::unordered_map<long, FT2Font *> char_to_font;
     FT_BBox bbox;
     FT_Pos advance;
     long hinting_factor;
